A driver code library for Text LCD panels using the 4-bit HD44780 lcd display driver.

Dependents:   Tarea2

Fork of TextLCD by David Godfrey

Revision:
8:122fc41ed965
Parent:
7:44f34c09bd37
Child:
9:e6111e52dd59
--- a/TextLCD.h	Sat Dec 04 11:29:57 2010 +0000
+++ b/TextLCD.h	Sun Dec 09 09:43:55 2012 +0000
@@ -27,13 +27,13 @@
 
 /** A TextLCD interface for driving 4-bit HD44780-based LCDs
  *
  * Currently supports 16x2, 20x2 and 20x4 panels
  *
  * @code
  * #include "mbed.h"
  * #include "TextLCD.h"
  * 
- * TextLCD lcd(p10, p12, p15, p16, p29, p30); // rs, e, d4-d7
+ * TextLCD lcd(p10, p12, p15, p16, p29, p30, TextLCD::LCD16x2); // rs, e, d4-d7, LCDType
  * 
  * int main() {
  *     lcd.printf("Hello World!\n");
@@ -49,6 +49,7 @@
         , LCD16x2B  /**< 16x2 LCD panel alternate addressing */
         , LCD20x2   /**< 20x2 LCD panel */
         , LCD20x4   /**< 20x4 LCD panel */
+        , LCD40x2   /**< 40x2 LCD panel */
     };
 
     /** Create a TextLCD interface
@@ -27,13 +27,13 @@
 /** A TextLCD interface for driving 4-bit HD44780-based LCDs
  *
- * Currently supports 16x2, 20x2 and 20x4 panels
+ * Currently supports 16x2, 20x2 , 20x4 and 40x2 panels
  *
  * @code